pub enum LayoutError {
Show 32 variants
MissingManifest(PathBuf),
MissingLib {
caixa: String,
expected: PathBuf,
},
BinarioWithoutExe(String),
ServicoWithoutServicos(String),
MissingEntry {
kind: &'static str,
path: PathBuf,
},
ExeOutsideDir(PathBuf),
ServicoOutsideDir(PathBuf),
NomeViolation {
caixa: String,
issue: String,
},
VersaoViolation {
caixa: String,
issue: String,
},
DepsViolation {
caixa: String,
issue: String,
},
EtiquetasViolation {
caixa: String,
issue: String,
},
AutoresViolation {
caixa: String,
issue: String,
},
RepositorioViolation {
caixa: String,
issue: String,
},
DescricaoViolation {
caixa: String,
issue: String,
},
LicencaViolation {
caixa: String,
issue: String,
},
EdicaoViolation {
caixa: String,
issue: String,
},
CodePathViolation {
caixa: String,
issue: String,
},
LimitsViolation {
caixa: String,
issue: String,
},
BehaviorViolation {
caixa: String,
issue: String,
},
UpgradeViolation {
caixa: String,
issue: String,
},
SupervisorViolation {
caixa: String,
issue: String,
},
RestartWindowViolation {
caixa: String,
issue: String,
},
SupervisorOwnsCode(String),
AplicacaoViolation {
caixa: String,
issue: String,
},
AplicacaoOwnsCode(String),
AcaoOwnsCode(String),
MeshSlotsOnNonAplicacao {
caixa: String,
kind: CaixaKind,
slots: String,
},
SupervisorSlotsOnNonSupervisor {
caixa: String,
kind: CaixaKind,
slots: String,
},
ServicoSlotsOnNonServico {
caixa: String,
kind: CaixaKind,
slots: String,
},
ForeignCodeSlot {
caixa: String,
kind: CaixaKind,
slots: String,
},
MissingCi(String),
CiOnNonAcao {
caixa: String,
kind: CaixaKind,
},
}Variants
MissingManifest(PathBuf)
MissingLib
BinarioWithoutExe(String)
ServicoWithoutServicos(String)
MissingEntry
ExeOutsideDir(PathBuf)
ServicoOutsideDir(PathBuf)
NomeViolation
VersaoViolation
DepsViolation
EtiquetasViolation
AutoresViolation
RepositorioViolation
DescricaoViolation
LicencaViolation
EdicaoViolation
CodePathViolation
LimitsViolation
BehaviorViolation
UpgradeViolation
SupervisorViolation
RestartWindowViolation
SupervisorOwnsCode(String)
AplicacaoViolation
AplicacaoOwnsCode(String)
AcaoOwnsCode(String)
MeshSlotsOnNonAplicacao
SupervisorSlotsOnNonSupervisor
ServicoSlotsOnNonServico
ForeignCodeSlot
MissingCi(String)
CiOnNonAcao
Implementations
Sourceimpl LayoutError
impl LayoutError
Sourcepub fn nome_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn nome_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::NomeViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn versao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn versao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::VersaoViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn deps_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn deps_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::DepsViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn etiquetas_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn etiquetas_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::EtiquetasViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn autores_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn autores_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::AutoresViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn repositorio_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn repositorio_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::RepositorioViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn descricao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn descricao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::DescricaoViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn licenca_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn licenca_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::LicencaViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn edicao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn edicao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::EdicaoViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn code_path_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn code_path_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::CodePathViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn limits_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn limits_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::LimitsViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn behavior_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn behavior_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::BehaviorViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn upgrade_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn upgrade_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::UpgradeViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn restart_window_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn restart_window_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::RestartWindowViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn supervisor_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn supervisor_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::SupervisorViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourcepub fn aplicacao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
pub fn aplicacao_violation<E: Display>(caixa: &Caixa, err: E) -> Self
Construct a LayoutError::AplicacaoViolation wrapping err under caixa.nome(). Folds the uniform { caixa: caixa.nome().to_string(), issue: err.to_string() } two-slot construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift five-line open-coded block.
Sourceimpl LayoutError
impl LayoutError
Sourcepub fn mesh_slots_on_non_aplicacao(
caixa: &Caixa,
slots: Vec<&'static str>,
) -> Self
pub fn mesh_slots_on_non_aplicacao( caixa: &Caixa, slots: Vec<&'static str>, ) -> Self
Construct a LayoutError::MeshSlotsOnNonAplicacao naming the offending slot list under caixa.nome() at caixa.kind(). Folds the uniform { caixa: caixa.nome().to_string(), kind: caixa.kind(), slots: slots.join(" ") } four-field construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift open-coded block.
Sourcepub fn supervisor_slots_on_non_supervisor(
caixa: &Caixa,
slots: Vec<&'static str>,
) -> Self
pub fn supervisor_slots_on_non_supervisor( caixa: &Caixa, slots: Vec<&'static str>, ) -> Self
Construct a LayoutError::SupervisorSlotsOnNonSupervisor naming the offending slot list under caixa.nome() at caixa.kind(). Folds the uniform { caixa: caixa.nome().to_string(), kind: caixa.kind(), slots: slots.join(" ") } four-field construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift open-coded block.
Sourcepub fn servico_slots_on_non_servico(
caixa: &Caixa,
slots: Vec<&'static str>,
) -> Self
pub fn servico_slots_on_non_servico( caixa: &Caixa, slots: Vec<&'static str>, ) -> Self
Construct a LayoutError::ServicoSlotsOnNonServico naming the offending slot list under caixa.nome() at caixa.kind(). Folds the uniform { caixa: caixa.nome().to_string(), kind: caixa.kind(), slots: slots.join(" ") } four-field construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift open-coded block.
Sourcepub fn foreign_code_slot(caixa: &Caixa, slots: Vec<&'static str>) -> Self
pub fn foreign_code_slot(caixa: &Caixa, slots: Vec<&'static str>) -> Self
Construct a LayoutError::ForeignCodeSlot naming the offending slot list under caixa.nome() at caixa.kind(). Folds the uniform { caixa: caixa.nome().to_string(), kind: caixa.kind(), slots: slots.join(" ") } four-field construction onto one substrate primitive so every StandardLayout::verify wire-up on this variant reads through one dispatch rather than the pre-lift open-coded block.