pub enum UpgradeError {
Show 17 variants
FromInvalid {
from: String,
reason: String,
},
ModuleEmpty {
kind: &'static str,
},
ModuleInvalid {
kind: &'static str,
module: String,
reason: String,
},
EmptyScript,
AbsoluteScript {
script: PathBuf,
},
ParentEscapeScript {
script: PathBuf,
},
NonLispExtensionScript {
script: PathBuf,
},
DuplicateFrom {
from: String,
},
FromNotBeforeVersao {
from: String,
versao: String,
},
RestartNotExclusive {
from: String,
restart_count: usize,
other_kinds: Vec<&'static str>,
},
StateChangeWithoutPriorLoad {
from: String,
script: PathBuf,
},
PurgeWithoutPriorLoad {
from: String,
kind: &'static str,
module: String,
},
DuplicateCleanup {
from: String,
module: String,
kinds: Vec<&'static str>,
},
DuplicateLoadModule {
from: String,
module: String,
},
DuplicateStateChange {
from: String,
script: PathBuf,
},
StateChangeAfterCleanup {
from: String,
script: PathBuf,
prior_cleanup_kind: &'static str,
prior_cleanup_module: String,
},
StateChangeWithoutOnStateChangeCallback {
from: String,
script: PathBuf,
},
}Variants
FromInvalid
ModuleEmpty
ModuleInvalid
EmptyScript
AbsoluteScript
ParentEscapeScript
NonLispExtensionScript
DuplicateFrom
FromNotBeforeVersao
RestartNotExclusive
StateChangeWithoutPriorLoad
PurgeWithoutPriorLoad
DuplicateCleanup
DuplicateLoadModule
DuplicateStateChange
StateChangeAfterCleanup
StateChangeWithoutOnStateChangeCallback
Implementations
Sourceimpl UpgradeError
impl UpgradeError
Sourcepub fn state_change_without_prior_load(from: &str, script: &Path) -> Self
pub fn state_change_without_prior_load(from: &str, script: &Path) -> Self
Construct an UpgradeError::StateChangeWithoutPriorLoad naming the offending (:from <prior-versao>) and (:state-change <script>) pair. Folds the uniform Self::StateChangeWithoutPriorLoad { from: from.to_string(), script: script.to_path_buf() } two-field struct-literal onto one substrate primitive so every wire-up on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The from string threads verbatim from UpgradeFromEntry::prior_versao and the script path from UpgradeInstruction::declared_path at the call site.
Sourcepub fn duplicate_state_change(from: &str, script: &Path) -> Self
pub fn duplicate_state_change(from: &str, script: &Path) -> Self
Construct an UpgradeError::DuplicateStateChange naming the offending (:from <prior-versao>) and (:state-change <script>) pair. Folds the uniform Self::DuplicateStateChange { from: from.to_string(), script: script.to_path_buf() } two-field struct-literal onto one substrate primitive so every wire-up on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The from string threads verbatim from UpgradeFromEntry::prior_versao and the script path from UpgradeInstruction::declared_path at the call site.
Sourcepub fn state_change_without_on_state_change_callback(
from: &str,
script: &Path,
) -> Self
pub fn state_change_without_on_state_change_callback( from: &str, script: &Path, ) -> Self
Construct an UpgradeError::StateChangeWithoutOnStateChangeCallback naming the offending (:from <prior-versao>) and (:state-change <script>) pair. Folds the uniform Self::StateChangeWithoutOnStateChangeCallback { from: from.to_string(), script: script.to_path_buf() } two-field struct-literal onto one substrate primitive so every wire-up on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The from string threads verbatim from UpgradeFromEntry::prior_versao and the script path from UpgradeInstruction::declared_path at the call site.
Sourceimpl UpgradeError
impl UpgradeError
Sourcepub fn absolute_script(script: &Path) -> Self
pub fn absolute_script(script: &Path) -> Self
Construct an UpgradeError::AbsoluteScript naming the offending (:state-change <script>). Folds the uniform Self::AbsoluteScript { script: script.to_path_buf() } one-field struct-literal onto one substrate primitive so every closure passed to crate::render::require_sandboxed_lisp_path at UpgradeInstruction::validate on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The script path threads verbatim from UpgradeInstruction::declared_path at the call site.
Sourcepub fn parent_escape_script(script: &Path) -> Self
pub fn parent_escape_script(script: &Path) -> Self
Construct an UpgradeError::ParentEscapeScript naming the offending (:state-change <script>). Folds the uniform Self::ParentEscapeScript { script: script.to_path_buf() } one-field struct-literal onto one substrate primitive so every closure passed to crate::render::require_sandboxed_lisp_path at UpgradeInstruction::validate on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The script path threads verbatim from UpgradeInstruction::declared_path at the call site.
Sourcepub fn non_lisp_extension_script(script: &Path) -> Self
pub fn non_lisp_extension_script(script: &Path) -> Self
Construct an UpgradeError::NonLispExtensionScript naming the offending (:state-change <script>). Folds the uniform Self::NonLispExtensionScript { script: script.to_path_buf() } one-field struct-literal onto one substrate primitive so every closure passed to crate::render::require_sandboxed_lisp_path at UpgradeInstruction::validate on this variant reads through one dispatch rather than the pre-lift three-line open-coded block. The script path threads verbatim from UpgradeInstruction::declared_path at the call site.